aboutsummaryrefslogtreecommitdiffstats
path: root/sys/decl.go
diff options
context:
space:
mode:
authorDmitry Vyukov <dvyukov@google.com>2017-01-08 17:20:32 +0100
committerDmitry Vyukov <dvyukov@google.com>2017-01-09 20:28:10 +0100
commitbbd4840872f70e3342308c6965ab196ed2606af1 (patch)
tree519ebfa1fbd6cafadd2efd1038e0c8f869ff37eb /sys/decl.go
parentc377a6514d9a4858e818e6d4637870bab2da6370 (diff)
sys: extend kvm support
Add new pseudo syscall syz_kvm_setup_cpu that setups VCPU into interesting states for execution. KVM is too difficult to setup otherwise. Lots of improvements possible, but this is a starting point.
Diffstat (limited to 'sys/decl.go')
-rw-r--r--sys/decl.go15
1 files changed, 13 insertions, 2 deletions
diff --git a/sys/decl.go b/sys/decl.go
index d09328c91..a8170e68d 100644
--- a/sys/decl.go
+++ b/sys/decl.go
@@ -104,13 +104,24 @@ const (
BufferBlobRange
BufferString
BufferFilename
+ BufferText
+)
+
+type TextKind int
+
+const (
+ Text_x86_real TextKind = iota
+ Text_x86_16
+ Text_x86_32
+ Text_x86_64
)
type BufferType struct {
TypeCommon
Kind BufferKind
- RangeBegin uintptr // for BufferBlobRange kind
- RangeEnd uintptr // for BufferBlobRange kind
+ RangeBegin uintptr // for BufferBlobRange kind
+ RangeEnd uintptr // for BufferBlobRange kind
+ Text TextKind // for BufferText
SubKind string
Values []string // possible values for BufferString kind
}